==> nextcloud-15.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/workflowengine/l10n/el.js <==
OC.L10N.register(
    "workflowengine",
    {
    "Short rule description" : "Μικρή περιγραφή κανόνα",
    "Add rule" : "Προσθέστε κανόνα",
    "Reset" : "Επαναφορά",
    "Save" : "Αποθήκευση",
    "Saving…" : "Αποθηκεύεται...",
    "Group list is empty" : "Η λίστα της ομάδας είναι κενή",
    "Unable to retrieve the group list" : "Αδύνατη η ανάκτηση λίστας της ομάδας",
    "Saved" : "Αποθηκεύτηκε",
    "Saving failed:" : "Απέτυχε η αποθήκευση:",
    "Add rule group" : "Προσθέστε κανόνα ομάδας",
    "File MIME type" : "Τύπος αρχείου MIME",
    "is" : "είναι",
    "is not" : "δεν είναι",
    "matches" : "ταιριάζει",
    "does not match" : "δεν ταιριάζει",
    "Example: {placeholder}" : "Παράδειγμα: {placeholder}",
    "File name" : "Όνομα αρχείου",
    "File size (upload)" : "Μέγεθος αρχείου (μεταφόρτωση)",
    "less" : "Λιγότερα",
    "less or equals" : "Λιγότερο ή ίσον",
    "greater or equals" : "είναι μεγαλύτερο ή ίσο",
    "greater" : "μεγαλύτερος",
    "File system tag" : "Ετικέτα συστήματος αρχείου",
    "is tagged with" : "έχει σημειωθεί με",
    "is not tagged with" : "δεν έχει σημειωθεί με",
    "Select tag…" : "Επιλέξτε ετικέτα...",
    "Request remote address" : "Αιτηθείτε απομακρυσμένη διέυθυνση",
    "matches IPv4" : "ταιριάζει IPv4",
    "does not match IPv4" : "δεν ταιριάζει IPv4",
    "matches IPv6" : "ταιριάζει με IPv6",
    "does not match IPv6" : "δεν ταιριάζει με IPv6",
    "Request time" : "Αιτηθείτε χρόνο",
    "between" : "μεταξύ",
    "not between" : "όχι μεταξύ",
    "Start" : "Έναρξη",
    "End" : "Λήξη",
    "Select timezone…" : "Επιλογή ζώνης ώρας...",
    "Request URL" : "Αιτηθείτε URL",
    "Predefined URLs" : "Προορισμένα URLs",
    "Files WebDAV" : "Αρχεία WebDAV",
    "Request user agent" : "Αιτηθείτε αντιπρόσωπο χρήστη",
    "Sync clients" : "Συγχρονίστε χρήστες",
    "Android client" : "Πελάτης Android",
    "iOS client" : "Πελάτης iOS",
    "Desktop client" : "Πελάτης σταθερού υπολογιστή",
    "User group membership" : "Συμμετοχή σε ομάδα χρηστών",
    "is member of" : "είναι μέλος του",
    "is not member of" : "δεν είναι μέλος του",
    "The given operator is invalid" : "Ο δοσμένος πάροχος δεν είναι έγκυρος",
    "The given regular expression is invalid" : "Η δοθείσα κανονική έκφραση δεν είναι έγκυρη",
    "The given file size is invalid" : "Το δοσμένο μέγεθος αρχείου δεν είναι έγκυρο",
    "The given tag id is invalid" : "Το δοσμένο id της ετικέτας δεν είναι έγκυρο",
    "The given IP range is invalid" : "Η δοσμένη περιοχή IP δεν είναι έγκυρη",
    "The given IP range is not valid for IPv4" : "Η δοσμένη περιοχή IP δεν είναι έγκυρη για IPv4",
    "The given IP range is not valid for IPv6" : "Η δοσμένη περιοχή IP δεν είναι έγκυρη για IPv6",
    "The given time span is invalid" : "Το δοσμένο χρονικό περιθώριο δεν είναι έγκυρο",
    "The given start time is invalid" : "Ο δοσμένος χρόνος έναρξης δεν είναι έγκυρος",
    "The given end time is invalid" : "Ο δοσμένος χρόνος λήξης δεν είναι έγκυρος",
    "The given group does not exist" : "Η δοσμένη ομάδα δεν υπάρχει",
    "Check %s is invalid or does not exist" : "Έλεγχος %s δεν είναι έγκυρος ή δεν υπάρχει",
    "Operation #%s does not exist" : "Λειτουργία #%s δεν υπάρχει",
    "Operation %s does not exist" : "Λειτουργία %s δεν υπάρχει",
    "Operation %s is invalid" : "Λειτουργία %s δεν είναι έγκυρη",
    "Check %s does not exist" : "Έλεγχος %s δεν υπάρχει",
    "Check %s is invalid" : "Έλεγχος %s δεν είναι έγκυρος",
    "Check #%s does not exist" : "Έλεγχος #%s δεν υπάρχει",
    "Workflow" : "Ροή εργασίας",
    "Open documentation" : "Άνοιγμα τεκμηρίωσης",
    "Loading…" : "Φορτώνει..."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-16.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/workflowengine/l10n/el.js <==
OC.L10N.register(
    "workflowengine",
    {
    "File MIME type" : "Τύπος αρχείου MIME",
    "is" : "είναι",
    "is not" : "δεν είναι",
    "matches" : "ταιριάζει",
    "does not match" : "δεν ταιριάζει",
    "Example: {placeholder}" : "Παράδειγμα: {placeholder}",
    "File name" : "Όνομα αρχείου",
    "File size (upload)" : "Μέγεθος αρχείου (μεταφόρτωση)",
    "less" : "Λιγότερα",
    "less or equals" : "Λιγότερο ή ίσον",
    "greater or equals" : "είναι μεγαλύτερο ή ίσο",
    "greater" : "μεγαλύτερος",
    "File system tag" : "Ετικέτα συστήματος αρχείου",
    "is tagged with" : "έχει σημειωθεί με",
    "is not tagged with" : "δεν έχει σημειωθεί με",
    "Select tag…" : "Επιλέξτε ετικέτα...",
    "Request remote address" : "Αιτηθείτε απομακρυσμένη διέυθυνση",
    "matches IPv4" : "ταιριάζει IPv4",
    "does not match IPv4" : "δεν ταιριάζει IPv4",
    "matches IPv6" : "ταιριάζει με IPv6",
    "does not match IPv6" : "δεν ταιριάζει με IPv6",
    "Request time" : "Αιτηθείτε χρόνο",
    "between" : "μεταξύ",
    "not between" : "όχι μεταξύ",
    "Start" : "Έναρξη",
    "End" : "Λήξη",
    "Select timezone…" : "Επιλογή ζώνης ώρας...",
    "Request URL" : "Αιτηθείτε URL",
    "Predefined URLs" : "Προορισμένα URLs",
    "Files WebDAV" : "Αρχεία WebDAV",
    "Request user agent" : "Αιτηθείτε αντιπρόσωπο χρήστη",
    "Sync clients" : "Συγχρονίστε χρήστες",
    "Android client" : "Πελάτης Android",
    "iOS client" : "Πελάτης iOS",
    "Desktop client" : "Πελάτης σταθερού υπολογιστή",
    "User group membership" : "Συμμετοχή σε ομάδα χρηστών",
    "is member of" : "είναι μέλος του",
    "is not member of" : "δεν είναι μέλος του",
    "Short rule description" : "Μικρή περιγραφή κανόνα",
    "Add rule" : "Προσθέστε κανόνα",
    "Reset" : "Επαναφορά",
    "Save" : "Αποθήκευση",
    "Saving…" : "Αποθηκεύεται...",
    "Group list is empty" : "Η λίστα της ομάδας είναι κενή",
    "Unable to retrieve the group list" : "Αδύνατη η ανάκτηση λίστας της ομάδας",
    "Saved" : "Αποθηκεύτηκε",
    "Saving failed:" : "Απέτυχε η αποθήκευση:",
    "Add rule group" : "Προσθέστε κανόνα ομάδας",
    "The given operator is invalid" : "Ο δοσμένος πάροχος δεν είναι έγκυρος",
    "The given regular expression is invalid" : "Η δοθείσα κανονική έκφραση δεν είναι έγκυρη",
    "The given file size is invalid" : "Το δοσμένο μέγεθος αρχείου δεν είναι έγκυρο",
    "The given tag id is invalid" : "Το δοσμένο id της ετικέτας δεν είναι έγκυρο",
    "The given IP range is invalid" : "Η δοσμένη περιοχή IP δεν είναι έγκυρη",
    "The given IP range is not valid for IPv4" : "Η δοσμένη περιοχή IP δεν είναι έγκυρη για IPv4",
    "The given IP range is not valid for IPv6" : "Η δοσμένη περιοχή IP δεν είναι έγκυρη για IPv6",
    "The given time span is invalid" : "Το δοσμένο χρονικό περιθώριο δεν είναι έγκυρο",
    "The given start time is invalid" : "Ο δοσμένος χρόνος έναρξης δεν είναι έγκυρος",
    "The given end time is invalid" : "Ο δοσμένος χρόνος λήξης δεν είναι έγκυρος",
    "The given group does not exist" : "Η δοσμένη ομάδα δεν υπάρχει",
    "Check %s is invalid or does not exist" : "Έλεγχος %s δεν είναι έγκυρος ή δεν υπάρχει",
    "Operation #%s does not exist" : "Λειτουργία #%s δεν υπάρχει",
    "Operation %s does not exist" : "Λειτουργία %s δεν υπάρχει",
    "Operation %s is invalid" : "Λειτουργία %s δεν είναι έγκυρη",
    "Check %s does not exist" : "Έλεγχος %s δεν υπάρχει",
    "Check %s is invalid" : "Έλεγχος %s δεν είναι έγκυρος",
    "Check #%s does not exist" : "Έλεγχος #%s δεν υπάρχει",
    "Open documentation" : "Άνοιγμα τεκμηρίωσης",
    "Loading…" : "Φορτώνει...",
    "Workflow" : "Ροή εργασίας"
},
"nplurals=2; plural=(n != 1);");
